@@ -1,4 +1,4 @@
-from typing import Any, Dict
+from typing import Any, Dict, cast
 
 import httpx
 from retrying import retry
@@ -11,21 +11,30 @@ from ...util.retry import DEFAULT_RETRY_ARGUMENTS
 
 def _get_kwargs(
     *,
+    client: httpx.Client,
     json_body: AuthResetPasswordRequest,
 ) -> Dict[str, Any]:
+    url = "{}/v1/auth:resetPassword".format(client.base_url)
+
+    headers = {k: v for (k, v) in client.headers.items()}
+    cookies = {k: v for (k, v) in client.cookies}
 
     json_json_body = json_body.to_dict()
 
     return {
+        "method": "post",
+        "url": url,
+        "headers": headers,
+        "cookies": cookies,
+        "timeout": client.timeout,
         "json": json_json_body,
     }
 
 
-def _parse_response(*, response: httpx.Response) -> None:
+def _parse_response(*, response: httpx.Response) -> Any:
     raise_for_status(response)
     if response.status_code == 204:
-        response_204 = None
-
+        response_204 = cast(Any, None)
         return response_204
     else:
         raise QCSHTTPStatusError(
@@ -33,7 +42,7 @@ def _parse_response(*, response: httpx.Response) -> None:
         )
 
 
-def _build_response(*, response: httpx.Response) -> Response[None]:
+def _build_response(*, response: httpx.Response) -> Response[Any]:
     """
     Construct the Response class from the raw ``httpx.Response``.
     """
@@ -45,17 +54,28 @@ def sync(
     *,
     client: httpx.Client,
     json_body: AuthResetPasswordRequest,
-) -> Response[None]:
-    url = "/v1/auth:resetPassword"
+    httpx_request_kwargs: Dict[str, Any] = {},
+) -> Response[Any]:
+    """Reset Password
+
+     Reset the password using the user's existing password. Note, this is an authenticated route.
+
+    Args:
+        json_body (AuthResetPasswordRequest):
+
+    Returns:
+        Response[Any]
+    """
 
     kwargs = _get_kwargs(
+        client=client,
         json_body=json_body,
     )
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
-        "post",
-        url,
         **kwargs,
     )
+
     return _build_response(response=response)
 
 
@@ -64,18 +84,16 @@ def sync_from_dict(
     *,
     client: httpx.Client,
     json_body_dict: Dict,
-) -> Response[None]:
+    httpx_request_kwargs: Dict[str, Any] = {},
+) -> Response[Any]:
     json_body = AuthResetPasswordRequest.from_dict(json_body_dict)
 
-    url = "/v1/auth:resetPassword"
-
     kwargs = _get_kwargs(
+        client=client,
         json_body=json_body,
     )
-
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
-        "post",
-        url,
         **kwargs,
     )
 
@@ -87,14 +105,27 @@ async def asyncio(
     *,
     client: httpx.AsyncClient,
     json_body: AuthResetPasswordRequest,
-) -> Response[None]:
-    url = "/v1/auth:resetPassword"
+    httpx_request_kwargs: Dict[str, Any] = {},
+) -> Response[Any]:
+    """Reset Password
+
+     Reset the password using the user's existing password. Note, this is an authenticated route.
+
+    Args:
+        json_body (AuthResetPasswordRequest):
+
+    Returns:
+        Response[Any]
+    """
 
     kwargs = _get_kwargs(
+        client=client,
         json_body=json_body,
     )
-
-    response = await client.request("post", url, **kwargs)
+    kwargs.update(httpx_request_kwargs)
+    response = await client.request(
+        **kwargs,
+    )
 
     return _build_response(response=response)
 
@@ -104,15 +135,17 @@ async def asyncio_from_dict(
     *,
     client: httpx.AsyncClient,
     json_body_dict: Dict,
-) -> Response[None]:
+    httpx_request_kwargs: Dict[str, Any] = {},
+) -> Response[Any]:
     json_body = AuthResetPasswordRequest.from_dict(json_body_dict)
 
-    url = "/v1/auth:resetPassword"
-
     kwargs = _get_kwargs(
+        client=client,
         json_body=json_body,
     )
-
-    response = await client.request("post", url, **kwargs)
+    kwargs.update(httpx_request_kwargs)
+    response = client.request(
+        **kwargs,
+    )
 
     return _build_response(response=response)
