@@ -9,9 +9,22 @@ from ...util.errors import QCSHTTPStatusError, raise_for_status
 from ...util.retry import DEFAULT_RETRY_ARGUMENTS
 
 
-def _get_kwargs() -> Dict[str, Any]:
+def _get_kwargs(
+    *,
+    client: httpx.Client,
+) -> Dict[str, Any]:
+    url = "{}/".format(client.base_url)
 
-    return {}
+    headers = {k: v for (k, v) in client.headers.items()}
+    cookies = {k: v for (k, v) in client.cookies}
+
+    return {
+        "method": "get",
+        "url": url,
+        "headers": headers,
+        "cookies": cookies,
+        "timeout": client.timeout,
+    }
 
 
 def _parse_response(*, response: httpx.Response) -> Health:
@@ -27,27 +40,32 @@ def _parse_response(*, response: httpx.Response) -> Health:
 
 
 def _build_response(*, response: httpx.Response) -> Response[Health]:
-    return Response(
-        status_code=response.status_code,
-        content=response.content,
-        headers=response.headers,
-        parsed=_parse_response(response=response),
-    )
+    """
+    Construct the Response class from the raw ``httpx.Response``.
+    """
+    return Response.build_from_httpx_response(response=response, parse_function=_parse_response)
 
 
 @retry(**DEFAULT_RETRY_ARGUMENTS)
 def sync(
     *,
     client: httpx.Client,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Health]:
-    url = "/"
+    """Retrieve the health status of the API
 
-    kwargs = _get_kwargs()
+    Returns:
+        Response[Health]
+    """
+
+    kwargs = _get_kwargs(
+        client=client,
+    )
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
-        "get",
-        url,
         **kwargs,
     )
+
     return _build_response(response=response)
 
 
@@ -55,15 +73,14 @@ def sync(
 def sync_from_dict(
     *,
     client: httpx.Client,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Health]:
 
-    url = "/"
-
-    kwargs = _get_kwargs()
-
+    kwargs = _get_kwargs(
+        client=client,
+    )
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
-        "get",
-        url,
         **kwargs,
     )
 
@@ -74,12 +91,21 @@ def sync_from_dict(
 async def asyncio(
     *,
     client: httpx.AsyncClient,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Health]:
-    url = "/"
+    """Retrieve the health status of the API
 
-    kwargs = _get_kwargs()
+    Returns:
+        Response[Health]
+    """
 
-    response = await client.request("get", url, **kwargs)
+    kwargs = _get_kwargs(
+        client=client,
+    )
+    kwargs.update(httpx_request_kwargs)
+    response = await client.request(
+        **kwargs,
+    )
 
     return _build_response(response=response)
 
@@ -88,12 +114,15 @@ async def asyncio(
 async def asyncio_from_dict(
     *,
     client: httpx.AsyncClient,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Health]:
 
-    url = "/"
-
-    kwargs = _get_kwargs()
-
-    response = await client.request("get", url, **kwargs)
+    kwargs = _get_kwargs(
+        client=client,
+    )
+    kwargs.update(httpx_request_kwargs)
+    response = client.request(
+        **kwargs,
+    )
 
     return _build_response(response=response)
