@@ -12,12 +12,22 @@ from ...util.retry import DEFAULT_RETRY_ARGUMENTS
 
 def _get_kwargs(
     *,
+    client: httpx.Client,
     json_body: CreateEndpointParameters,
 ) -> Dict[str, Any]:
+    url = "{}/v1/endpoints".format(client.base_url)
+
+    headers = {k: v for (k, v) in client.headers.items()}
+    cookies = {k: v for (k, v) in client.cookies}
 
     json_json_body = json_body.to_dict()
 
     return {
+        "method": "post",
+        "url": url,
+        "headers": headers,
+        "cookies": cookies,
+        "timeout": client.timeout,
         "json": json_json_body,
     }
 
@@ -46,17 +56,29 @@ def sync(
     *,
     client: httpx.Client,
     json_body: CreateEndpointParameters,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Endpoint]:
-    url = "/v1/endpoints"
+    """Create Endpoint
+
+     Create an endpoint associated with your user account.
+
+    Args:
+        json_body (CreateEndpointParameters): A publicly available set of parameters for defining
+            an endpoint.
+
+    Returns:
+        Response[Endpoint]
+    """
 
     kwargs = _get_kwargs(
+        client=client,
         json_body=json_body,
     )
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
-        "post",
-        url,
         **kwargs,
     )
+
     return _build_response(response=response)
 
 
@@ -65,18 +87,16 @@ def sync_from_dict(
     *,
     client: httpx.Client,
     json_body_dict: Dict,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Endpoint]:
     json_body = CreateEndpointParameters.from_dict(json_body_dict)
 
-    url = "/v1/endpoints"
-
     kwargs = _get_kwargs(
+        client=client,
         json_body=json_body,
     )
-
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
-        "post",
-        url,
         **kwargs,
     )
 
@@ -88,14 +108,28 @@ async def asyncio(
     *,
     client: httpx.AsyncClient,
     json_body: CreateEndpointParameters,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Endpoint]:
-    url = "/v1/endpoints"
+    """Create Endpoint
+
+     Create an endpoint associated with your user account.
+
+    Args:
+        json_body (CreateEndpointParameters): A publicly available set of parameters for defining
+            an endpoint.
+
+    Returns:
+        Response[Endpoint]
+    """
 
     kwargs = _get_kwargs(
+        client=client,
         json_body=json_body,
     )
-
-    response = await client.request("post", url, **kwargs)
+    kwargs.update(httpx_request_kwargs)
+    response = await client.request(
+        **kwargs,
+    )
 
     return _build_response(response=response)
 
@@ -105,15 +139,17 @@ async def asyncio_from_dict(
     *,
     client: httpx.AsyncClient,
     json_body_dict: Dict,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Endpoint]:
     json_body = CreateEndpointParameters.from_dict(json_body_dict)
 
-    url = "/v1/endpoints"
-
     kwargs = _get_kwargs(
+        client=client,
         json_body=json_body,
     )
-
-    response = await client.request("post", url, **kwargs)
+    kwargs.update(httpx_request_kwargs)
+    response = client.request(
+        **kwargs,
+    )
 
     return _build_response(response=response)
