@@ -10,11 +10,24 @@ from ...util.retry import DEFAULT_RETRY_ARGUMENTS
 
 
 def _get_kwargs(
-    *,
     quantum_processor_id: str,
+    *,
+    client: httpx.Client,
 ) -> Dict[str, Any]:
+    url = "{}/v1/quantumProcessors/{quantumProcessorId}/endpoints:getDefault".format(
+        client.base_url, quantumProcessorId=quantum_processor_id
+    )
 
-    return {}
+    headers = {k: v for (k, v) in client.headers.items()}
+    cookies = {k: v for (k, v) in client.cookies}
+
+    return {
+        "method": "get",
+        "url": url,
+        "headers": headers,
+        "cookies": cookies,
+        "timeout": client.timeout,
+    }
 
 
 def _parse_response(*, response: httpx.Response) -> Endpoint:
@@ -38,43 +51,50 @@ def _build_response(*, response: httpx.Response) -> Response[Endpoint]:
 
 @retry(**DEFAULT_RETRY_ARGUMENTS)
 def sync(
+    quantum_processor_id: str,
     *,
     client: httpx.Client,
-    quantum_processor_id: str,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Endpoint]:
-    url = "/v1/quantumProcessors/{quantumProcessorId}/endpoints:getDefault".format(
-        quantumProcessorId=quantum_processor_id,
-    )
+    """Get Default Endpoint
+
+     Retrieve the endpoint set as \"default\" for the given Quantum Processor.
+
+    If no endpoint is set as the default, return \"not found.\"
+
+    Args:
+        quantum_processor_id (str): Public identifier for a quantum processor [example: Aspen-1]
+
+    Returns:
+        Response[Endpoint]
+    """
 
     kwargs = _get_kwargs(
         quantum_processor_id=quantum_processor_id,
+        client=client,
     )
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
-        "get",
-        url,
         **kwargs,
     )
+
     return _build_response(response=response)
 
 
 @retry(**DEFAULT_RETRY_ARGUMENTS)
 def sync_from_dict(
+    quantum_processor_id: str,
     *,
     client: httpx.Client,
-    quantum_processor_id: str,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Endpoint]:
 
-    url = "/v1/quantumProcessors/{quantumProcessorId}/endpoints:getDefault".format(
-        quantumProcessorId=quantum_processor_id,
-    )
-
     kwargs = _get_kwargs(
         quantum_processor_id=quantum_processor_id,
+        client=client,
     )
-
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
-        "get",
-        url,
         **kwargs,
     )
 
@@ -83,38 +103,51 @@ def sync_from_dict(
 
 @retry(**DEFAULT_RETRY_ARGUMENTS)
 async def asyncio(
+    quantum_processor_id: str,
     *,
     client: httpx.AsyncClient,
-    quantum_processor_id: str,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Endpoint]:
-    url = "/v1/quantumProcessors/{quantumProcessorId}/endpoints:getDefault".format(
-        quantumProcessorId=quantum_processor_id,
-    )
+    """Get Default Endpoint
+
+     Retrieve the endpoint set as \"default\" for the given Quantum Processor.
+
+    If no endpoint is set as the default, return \"not found.\"
+
+    Args:
+        quantum_processor_id (str): Public identifier for a quantum processor [example: Aspen-1]
+
+    Returns:
+        Response[Endpoint]
+    """
 
     kwargs = _get_kwargs(
         quantum_processor_id=quantum_processor_id,
+        client=client,
+    )
+    kwargs.update(httpx_request_kwargs)
+    response = await client.request(
+        **kwargs,
     )
-
-    response = await client.request("get", url, **kwargs)
 
     return _build_response(response=response)
 
 
 @retry(**DEFAULT_RETRY_ARGUMENTS)
 async def asyncio_from_dict(
+    quantum_processor_id: str,
     *,
     client: httpx.AsyncClient,
-    quantum_processor_id: str,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Endpoint]:
 
-    url = "/v1/quantumProcessors/{quantumProcessorId}/endpoints:getDefault".format(
-        quantumProcessorId=quantum_processor_id,
-    )
-
     kwargs = _get_kwargs(
         quantum_processor_id=quantum_processor_id,
+        client=client,
+    )
+    kwargs.update(httpx_request_kwargs)
+    response = client.request(
+        **kwargs,
     )
 
-    response = await client.request("get", url, **kwargs)
-
     return _build_response(response=response)
