@@ -6,28 +6,41 @@ from retrying import retry
 from rfc3339 import rfc3339
 
 from ...models.find_available_reservations_response import FindAvailableReservationsResponse
-from ...types import Response
+from ...types import UNSET, Response
 from ...util.errors import QCSHTTPStatusError, raise_for_status
 from ...util.retry import DEFAULT_RETRY_ARGUMENTS
 
 
 def _get_kwargs(
     *,
+    client: httpx.Client,
     quantum_processor_id: str,
     start_time_from: datetime.datetime,
     duration: str,
 ) -> Dict[str, Any]:
+    url = "{}/v1/reservations:findAvailable".format(client.base_url)
+
+    headers = {k: v for (k, v) in client.headers.items()}
+    cookies = {k: v for (k, v) in client.cookies}
+
+    params: Dict[str, Any] = {}
+    params["quantumProcessorId"] = quantum_processor_id
 
     assert start_time_from.tzinfo is not None, "Datetime must have timezone information"
     json_start_time_from = rfc3339(start_time_from)
 
-    params: Dict[str, Any] = {
-        "quantumProcessorId": quantum_processor_id,
-        "startTimeFrom": json_start_time_from,
-        "duration": duration,
-    }
+    params["startTimeFrom"] = json_start_time_from
+
+    params["duration"] = duration
+
+    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
+        "method": "get",
+        "url": url,
+        "headers": headers,
+        "cookies": cookies,
+        "timeout": client.timeout,
         "params": params,
     }
 
@@ -58,19 +71,33 @@ def sync(
     quantum_processor_id: str,
     start_time_from: datetime.datetime,
     duration: str,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[FindAvailableReservationsResponse]:
-    url = "/v1/reservations:findAvailable"
+    """Find Available Reservations
+
+     List currently available reservations on the requested Rigetti quantum computer.
+
+    Args:
+        quantum_processor_id (str):
+        start_time_from (datetime.datetime):
+        duration (str): Formatted as specified for golang
+            https://golang.org/pkg/time/#ParseDuration.
+
+    Returns:
+        Response[FindAvailableReservationsResponse]
+    """
 
     kwargs = _get_kwargs(
+        client=client,
         quantum_processor_id=quantum_processor_id,
         start_time_from=start_time_from,
         duration=duration,
     )
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
-        "get",
-        url,
         **kwargs,
     )
+
     return _build_response(response=response)
 
 
@@ -81,19 +108,17 @@ def sync_from_dict(
     quantum_processor_id: str,
     start_time_from: datetime.datetime,
     duration: str,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[FindAvailableReservationsResponse]:
 
-    url = "/v1/reservations:findAvailable"
-
     kwargs = _get_kwargs(
+        client=client,
         quantum_processor_id=quantum_processor_id,
         start_time_from=start_time_from,
         duration=duration,
     )
-
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
-        "get",
-        url,
         **kwargs,
     )
 
@@ -107,16 +132,32 @@ async def asyncio(
     quantum_processor_id: str,
     start_time_from: datetime.datetime,
     duration: str,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[FindAvailableReservationsResponse]:
-    url = "/v1/reservations:findAvailable"
+    """Find Available Reservations
+
+     List currently available reservations on the requested Rigetti quantum computer.
+
+    Args:
+        quantum_processor_id (str):
+        start_time_from (datetime.datetime):
+        duration (str): Formatted as specified for golang
+            https://golang.org/pkg/time/#ParseDuration.
+
+    Returns:
+        Response[FindAvailableReservationsResponse]
+    """
 
     kwargs = _get_kwargs(
+        client=client,
         quantum_processor_id=quantum_processor_id,
         start_time_from=start_time_from,
         duration=duration,
     )
-
-    response = await client.request("get", url, **kwargs)
+    kwargs.update(httpx_request_kwargs)
+    response = await client.request(
+        **kwargs,
+    )
 
     return _build_response(response=response)
 
@@ -128,16 +169,18 @@ async def asyncio_from_dict(
     quantum_processor_id: str,
     start_time_from: datetime.datetime,
     duration: str,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[FindAvailableReservationsResponse]:
 
-    url = "/v1/reservations:findAvailable"
-
     kwargs = _get_kwargs(
+        client=client,
         quantum_processor_id=quantum_processor_id,
         start_time_from=start_time_from,
         duration=duration,
     )
-
-    response = await client.request("get", url, **kwargs)
+    kwargs.update(httpx_request_kwargs)
+    response = client.request(
+        **kwargs,
+    )
 
     return _build_response(response=response)
