@@ -1,4 +1,4 @@
-from typing import Any, Callable, Dict, List, Optional, Union, cast
+from typing import Any, Callable, Dict, List, Optional, Type, TypeVar, Union, cast
 
 import attr
 
@@ -8,14 +8,25 @@ from ..models.translate_native_quil_to_encrypted_binary_response_memory_descript
 from ..types import UNSET, Unset
 from ..util.serialization import is_not_none
 
+T = TypeVar("T", bound="TranslateNativeQuilToEncryptedBinaryResponse")
+
 
 @attr.s(auto_attribs=True)
 class TranslateNativeQuilToEncryptedBinaryResponse:
-    """  """
+    """
+    Attributes:
+        program (str): Encrypted binary built for execution on the target quantum processor
+        memory_descriptors (Union[Unset, TranslateNativeQuilToEncryptedBinaryResponseMemoryDescriptors]):
+        ro_sources (Union[Unset, List[List[str]]]):
+        settings_timestamp (Union[Unset, str]): ISO8601 timestamp of the settings used to translate the program.
+            Translation is deterministic; a program translated twice with the same settings by the same version of the
+            service will have identical output.
+    """
 
     program: str
-    memory_descriptors: Union[TranslateNativeQuilToEncryptedBinaryResponseMemoryDescriptors, Unset] = UNSET
+    memory_descriptors: Union[Unset, TranslateNativeQuilToEncryptedBinaryResponseMemoryDescriptors] = UNSET
     ro_sources: Union[Unset, List[List[str]]] = UNSET
+    settings_timestamp: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self, pick_by_predicate: Optional[Callable[[Any], bool]] = is_not_none) -> Dict[str, Any]:
@@ -24,7 +35,7 @@ class TranslateNativeQuilToEncryptedBinaryResponse:
         if not isinstance(self.memory_descriptors, Unset):
             memory_descriptors = self.memory_descriptors.to_dict()
 
-        ro_sources: Union[Unset, List[Any]] = UNSET
+        ro_sources: Union[Unset, List[List[str]]] = UNSET
         if not isinstance(self.ro_sources, Unset):
             ro_sources = []
             for ro_sources_item_data in self.ro_sources:
@@ -32,6 +43,8 @@ class TranslateNativeQuilToEncryptedBinaryResponse:
 
                 ro_sources.append(ro_sources_item)
 
+        settings_timestamp = self.settings_timestamp
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -43,6 +56,8 @@ class TranslateNativeQuilToEncryptedBinaryResponse:
             field_dict["memoryDescriptors"] = memory_descriptors
         if ro_sources is not UNSET:
             field_dict["roSources"] = ro_sources
+        if settings_timestamp is not UNSET:
+            field_dict["settingsTimestamp"] = settings_timestamp
 
         field_dict = {k: v for k, v in field_dict.items() if v != UNSET}
         if pick_by_predicate is not None:
@@ -50,16 +65,18 @@ class TranslateNativeQuilToEncryptedBinaryResponse:
 
         return field_dict
 
-    @staticmethod
-    def from_dict(src_dict: Dict[str, Any]) -> "TranslateNativeQuilToEncryptedBinaryResponse":
+    @classmethod
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
         program = d.pop("program")
 
-        memory_descriptors: Union[TranslateNativeQuilToEncryptedBinaryResponseMemoryDescriptors, Unset] = UNSET
         _memory_descriptors = d.pop("memoryDescriptors", UNSET)
-        if _memory_descriptors is not None and not isinstance(_memory_descriptors, Unset):
+        memory_descriptors: Union[Unset, TranslateNativeQuilToEncryptedBinaryResponseMemoryDescriptors]
+        if isinstance(_memory_descriptors, Unset):
+            memory_descriptors = UNSET
+        else:
             memory_descriptors = TranslateNativeQuilToEncryptedBinaryResponseMemoryDescriptors.from_dict(
-                cast(Dict[str, Any], _memory_descriptors)
+                _memory_descriptors
             )
 
         ro_sources = []
@@ -69,10 +86,13 @@ class TranslateNativeQuilToEncryptedBinaryResponse:
 
             ro_sources.append(ro_sources_item)
 
-        translate_native_quil_to_encrypted_binary_response = TranslateNativeQuilToEncryptedBinaryResponse(
+        settings_timestamp = d.pop("settingsTimestamp", UNSET)
+
+        translate_native_quil_to_encrypted_binary_response = cls(
             program=program,
             memory_descriptors=memory_descriptors,
             ro_sources=ro_sources,
+            settings_timestamp=settings_timestamp,
         )
 
         translate_native_quil_to_encrypted_binary_response.additional_properties = d
